package com.mysql.jdbc;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Properties;
import java.util.Set;
import java.util.TreeMap;

/* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/CharsetMapping.class */
public class CharsetMapping {
    private static final Properties CHARSET_CONFIG = new Properties();
    public static final String[] INDEX_TO_CHARSET;
    public static final String[] INDEX_TO_COLLATION;
    private static final Map JAVA_TO_MYSQL_CHARSET_MAP;
    private static final Map JAVA_UC_TO_MYSQL_CHARSET_MAP;
    private static final Map ERROR_MESSAGE_FILE_TO_MYSQL_CHARSET_MAP;
    private static final Map MULTIBYTE_CHARSETS;
    private static final Map MYSQL_TO_JAVA_CHARSET_MAP;
    private static final Map MYSQL_ENCODING_NAME_TO_CHARSET_INDEX_MAP;
    private static final String NOT_USED = "ISO8859_1";
    public static final Map STATIC_CHARSET_TO_NUM_BYTES_MAP;

    static {
        HashMap tempNumBytesMap = new HashMap();
        tempNumBytesMap.put("big5", Constants.integerValueOf(2));
        tempNumBytesMap.put("dec8", Constants.integerValueOf(1));
        tempNumBytesMap.put("cp850", Constants.integerValueOf(1));
        tempNumBytesMap.put("hp8", Constants.integerValueOf(1));
        tempNumBytesMap.put("koi8r", Constants.integerValueOf(1));
        tempNumBytesMap.put("latin1", Constants.integerValueOf(1));
        tempNumBytesMap.put("latin2", Constants.integerValueOf(1));
        tempNumBytesMap.put("swe7", Constants.integerValueOf(1));
        tempNumBytesMap.put("ascii", Constants.integerValueOf(1));
        tempNumBytesMap.put("ujis", Constants.integerValueOf(3));
        tempNumBytesMap.put("sjis", Constants.integerValueOf(2));
        tempNumBytesMap.put("hebrew", Constants.integerValueOf(1));
        tempNumBytesMap.put("tis620", Constants.integerValueOf(1));
        tempNumBytesMap.put("euckr", Constants.integerValueOf(2));
        tempNumBytesMap.put("koi8u", Constants.integerValueOf(1));
        tempNumBytesMap.put("gb2312", Constants.integerValueOf(2));
        tempNumBytesMap.put("greek", Constants.integerValueOf(1));
        tempNumBytesMap.put("cp1250", Constants.integerValueOf(1));
        tempNumBytesMap.put("gbk", Constants.integerValueOf(2));
        tempNumBytesMap.put("latin5", Constants.integerValueOf(1));
        tempNumBytesMap.put("armscii8", Constants.integerValueOf(1));
        tempNumBytesMap.put("utf8", Constants.integerValueOf(3));
        tempNumBytesMap.put("ucs2", Constants.integerValueOf(2));
        tempNumBytesMap.put("cp866", Constants.integerValueOf(1));
        tempNumBytesMap.put("keybcs2", Constants.integerValueOf(1));
        tempNumBytesMap.put("macce", Constants.integerValueOf(1));
        tempNumBytesMap.put("macroman", Constants.integerValueOf(1));
        tempNumBytesMap.put("cp852", Constants.integerValueOf(1));
        tempNumBytesMap.put("latin7", Constants.integerValueOf(1));
        tempNumBytesMap.put("cp1251", Constants.integerValueOf(1));
        tempNumBytesMap.put("cp1256", Constants.integerValueOf(1));
        tempNumBytesMap.put("cp1257", Constants.integerValueOf(1));
        tempNumBytesMap.put("binary", Constants.integerValueOf(1));
        tempNumBytesMap.put("geostd8", Constants.integerValueOf(1));
        tempNumBytesMap.put("cp932", Constants.integerValueOf(2));
        tempNumBytesMap.put("eucjpms", Constants.integerValueOf(3));
        STATIC_CHARSET_TO_NUM_BYTES_MAP = Collections.unmodifiableMap(tempNumBytesMap);
        CHARSET_CONFIG.setProperty("javaToMysqlMappings", "US-ASCII =\t\t\tusa7,US-ASCII =\t\t\t>4.1.0 ascii,Big5 = \t\t\t\tbig5,GBK = \t\t\t\tgbk,SJIS = \t\t\t\tsjis,EUC_CN = \t\t\tgb2312,EUC_JP = \t\t\tujis,EUC_JP_Solaris = \t>5.0.3 eucjpms,EUC_KR = \t\t\teuc_kr,EUC_KR = \t\t\t>4.1.0 euckr,ISO8859_1 =\t\t\t*latin1,ISO8859_1 =\t\t\tlatin1_de,ISO8859_1 =\t\t\tgerman1,ISO8859_1 =\t\t\tdanish,ISO8859_2 =\t\t\tlatin2,ISO8859_2 =\t\t\tczech,ISO8859_2 =\t\t\thungarian,ISO8859_2  =\t\tcroat,ISO8859_7  =\t\tgreek,ISO8859_7  =\t\tlatin7,ISO8859_8  = \t\thebrew,ISO8859_9  =\t\tlatin5,ISO8859_13 =\t\tlatvian,ISO8859_13 =\t\tlatvian1,ISO8859_13 =\t\testonia,Cp437 =             *>4.1.0 cp850,Cp437 =\t\t\t\tdos,Cp850 =\t\t\t\tcp850,Cp852 = \t\t\tcp852,Cp866 = \t\t\tcp866,KOI8_R = \t\t\tkoi8_ru,KOI8_R = \t\t\t>4.1.0 koi8r,TIS620 = \t\t\ttis620,Cp1250 = \t\t\tcp1250,Cp1250 = \t\t\twin1250,Cp1251 = \t\t\t*>4.1.0 cp1251,Cp1251 = \t\t\twin1251,Cp1251 = \t\t\tcp1251cias,Cp1251 = \t\t\tcp1251csas,Cp1256 = \t\t\tcp1256,Cp1251 = \t\t\twin1251ukr,Cp1252 =             latin1,Cp1257 = \t\t\tcp1257,MacRoman = \t\t\tmacroman,MacCentralEurope = \tmacce,UTF-8 = \t\tutf8,UnicodeBig = \tucs2,US-ASCII =\t\tbinary,Cp943 =        \tsjis,MS932 =\t\t\tsjis,MS932 =        \t>4.1.11 cp932,WINDOWS-31J =\tsjis,WINDOWS-31J = \t>4.1.11 cp932,CP932 =\t\t\tsjis,CP932 =\t\t\t*>4.1.11 cp932,SHIFT_JIS = \tsjis,ASCII =\t\t\tascii,LATIN5 =\t\tlatin5,LATIN7 =\t\tlatin7,HEBREW =\t\thebrew,GREEK =\t\t\tgreek,EUCKR =\t\t\teuckr,GB2312 =\t\tgb2312,LATIN2 =\t\tlatin2");
        HashMap javaToMysqlMap = new HashMap();
        populateMapWithKeyValuePairs("javaToMysqlMappings", javaToMysqlMap, true, false);
        JAVA_TO_MYSQL_CHARSET_MAP = Collections.unmodifiableMap(javaToMysqlMap);
        HashMap mysqlToJavaMap = new HashMap();
        Set keySet = JAVA_TO_MYSQL_CHARSET_MAP.keySet();
        for (Object javaEncodingName : keySet) {
            List<VersionedStringProperty> mysqlEncodingList = (List) JAVA_TO_MYSQL_CHARSET_MAP.get(javaEncodingName);
            for (VersionedStringProperty mysqlProp : mysqlEncodingList) {
                String mysqlEncodingName = mysqlProp.toString();
                mysqlToJavaMap.put(mysqlEncodingName, javaEncodingName);
                mysqlToJavaMap.put(mysqlEncodingName.toUpperCase(Locale.ENGLISH), javaEncodingName);
            }
        }
        mysqlToJavaMap.put("cp932", "Windows-31J");
        mysqlToJavaMap.put("CP932", "Windows-31J");
        MYSQL_TO_JAVA_CHARSET_MAP = Collections.unmodifiableMap(mysqlToJavaMap);
        TreeMap ucMap = new TreeMap(String.CASE_INSENSITIVE_ORDER);
        for (String key : JAVA_TO_MYSQL_CHARSET_MAP.keySet()) {
            ucMap.put(key.toUpperCase(Locale.ENGLISH), JAVA_TO_MYSQL_CHARSET_MAP.get(key));
        }
        JAVA_UC_TO_MYSQL_CHARSET_MAP = Collections.unmodifiableMap(ucMap);
        HashMap tempMapMulti = new HashMap();
        CHARSET_CONFIG.setProperty("multibyteCharsets", "Big5 = \t\t\tbig5,GBK = \t\t\tgbk,SJIS = \t\t\tsjis,EUC_CN = \t\tgb2312,EUC_JP = \t\tujis,EUC_JP_Solaris = eucjpms,EUC_KR = \t\teuc_kr,EUC_KR = \t\t>4.1.0 euckr,Cp943 =        \tsjis,Cp943 = \t\tcp943,WINDOWS-31J =\tsjis,WINDOWS-31J = \tcp932,CP932 =\t\t\tcp932,MS932 =\t\t\tsjis,MS932 =        \tcp932,SHIFT_JIS = \tsjis,EUCKR =\t\t\teuckr,GB2312 =\t\tgb2312,UTF-8 = \t\tutf8,utf8 =          utf8,UnicodeBig = \tucs2");
        populateMapWithKeyValuePairs("multibyteCharsets", tempMapMulti, false, true);
        MULTIBYTE_CHARSETS = Collections.unmodifiableMap(tempMapMulti);
        INDEX_TO_CHARSET = new String[211];
        try {
            INDEX_TO_CHARSET[1] = getJavaEncodingForMysqlEncoding("big5", null);
            INDEX_TO_CHARSET[2] = getJavaEncodingForMysqlEncoding("czech", null);
            INDEX_TO_CHARSET[3] = NOT_USED;
            INDEX_TO_CHARSET[4] = NOT_USED;
            INDEX_TO_CHARSET[5] = getJavaEncodingForMysqlEncoding("german1", null);
            INDEX_TO_CHARSET[6] = NOT_USED;
            INDEX_TO_CHARSET[7] = getJavaEncodingForMysqlEncoding("koi8_ru", null);
            INDEX_TO_CHARSET[8] = getJavaEncodingForMysqlEncoding("latin1", null);
            INDEX_TO_CHARSET[9] = getJavaEncodingForMysqlEncoding("latin2", null);
            INDEX_TO_CHARSET[10] = NOT_USED;
            INDEX_TO_CHARSET[11] = getJavaEncodingForMysqlEncoding("usa7", null);
            INDEX_TO_CHARSET[12] = getJavaEncodingForMysqlEncoding("ujis", null);
            INDEX_TO_CHARSET[13] = getJavaEncodingForMysqlEncoding("sjis", null);
            INDEX_TO_CHARSET[14] = getJavaEncodingForMysqlEncoding("cp1251", null);
            INDEX_TO_CHARSET[15] = getJavaEncodingForMysqlEncoding("danish", null);
            INDEX_TO_CHARSET[16] = getJavaEncodingForMysqlEncoding("hebrew", null);
            INDEX_TO_CHARSET[17] = NOT_USED;
            INDEX_TO_CHARSET[18] = getJavaEncodingForMysqlEncoding("tis620", null);
            INDEX_TO_CHARSET[19] = getJavaEncodingForMysqlEncoding("euc_kr", null);
            INDEX_TO_CHARSET[20] = getJavaEncodingForMysqlEncoding("estonia", null);
            INDEX_TO_CHARSET[21] = getJavaEncodingForMysqlEncoding("hungarian", null);
            INDEX_TO_CHARSET[22] = "KOI8_R";
            INDEX_TO_CHARSET[23] = getJavaEncodingForMysqlEncoding("win1251ukr", null);
            INDEX_TO_CHARSET[24] = getJavaEncodingForMysqlEncoding("gb2312", null);
            INDEX_TO_CHARSET[25] = getJavaEncodingForMysqlEncoding("greek", null);
            INDEX_TO_CHARSET[26] = getJavaEncodingForMysqlEncoding("win1250", null);
            INDEX_TO_CHARSET[27] = getJavaEncodingForMysqlEncoding("croat", null);
            INDEX_TO_CHARSET[28] = getJavaEncodingForMysqlEncoding("gbk", null);
            INDEX_TO_CHARSET[29] = getJavaEncodingForMysqlEncoding("cp1257", null);
            INDEX_TO_CHARSET[30] = getJavaEncodingForMysqlEncoding("latin5", null);
            INDEX_TO_CHARSET[31] = getJavaEncodingForMysqlEncoding("latin1_de", null);
            INDEX_TO_CHARSET[32] = NOT_USED;
            INDEX_TO_CHARSET[33] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[34] = "Cp1250";
            INDEX_TO_CHARSET[35] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[36] = getJavaEncodingForMysqlEncoding("cp866", null);
            INDEX_TO_CHARSET[37] = "Cp895";
            INDEX_TO_CHARSET[38] = getJavaEncodingForMysqlEncoding("macce", null);
            INDEX_TO_CHARSET[39] = getJavaEncodingForMysqlEncoding("macroman", null);
            INDEX_TO_CHARSET[40] = "latin2";
            INDEX_TO_CHARSET[41] = getJavaEncodingForMysqlEncoding("latvian", null);
            INDEX_TO_CHARSET[42] = getJavaEncodingForMysqlEncoding("latvian1", null);
            INDEX_TO_CHARSET[43] = getJavaEncodingForMysqlEncoding("macce", null);
            INDEX_TO_CHARSET[44] = getJavaEncodingForMysqlEncoding("macce", null);
            INDEX_TO_CHARSET[45] = getJavaEncodingForMysqlEncoding("macce", null);
            INDEX_TO_CHARSET[46] = getJavaEncodingForMysqlEncoding("macce", null);
            INDEX_TO_CHARSET[47] = getJavaEncodingForMysqlEncoding("latin1", null);
            INDEX_TO_CHARSET[48] = getJavaEncodingForMysqlEncoding("latin1", null);
            INDEX_TO_CHARSET[49] = getJavaEncodingForMysqlEncoding("latin1", null);
            INDEX_TO_CHARSET[50] = getJavaEncodingForMysqlEncoding("cp1251", null);
            INDEX_TO_CHARSET[51] = getJavaEncodingForMysqlEncoding("cp1251", null);
            INDEX_TO_CHARSET[52] = getJavaEncodingForMysqlEncoding("cp1251", null);
            INDEX_TO_CHARSET[53] = getJavaEncodingForMysqlEncoding("macroman", null);
            INDEX_TO_CHARSET[54] = getJavaEncodingForMysqlEncoding("macroman", null);
            INDEX_TO_CHARSET[55] = getJavaEncodingForMysqlEncoding("macroman", null);
            INDEX_TO_CHARSET[56] = getJavaEncodingForMysqlEncoding("macroman", null);
            INDEX_TO_CHARSET[57] = getJavaEncodingForMysqlEncoding("cp1256", null);
            INDEX_TO_CHARSET[58] = NOT_USED;
            INDEX_TO_CHARSET[59] = NOT_USED;
            INDEX_TO_CHARSET[60] = NOT_USED;
            INDEX_TO_CHARSET[61] = NOT_USED;
            INDEX_TO_CHARSET[62] = NOT_USED;
            INDEX_TO_CHARSET[63] = getJavaEncodingForMysqlEncoding("binary", null);
            INDEX_TO_CHARSET[64] = "ISO8859_2";
            INDEX_TO_CHARSET[65] = getJavaEncodingForMysqlEncoding("ascii", null);
            INDEX_TO_CHARSET[66] = getJavaEncodingForMysqlEncoding("cp1250", null);
            INDEX_TO_CHARSET[67] = getJavaEncodingForMysqlEncoding("cp1256", null);
            INDEX_TO_CHARSET[68] = getJavaEncodingForMysqlEncoding("cp866", null);
            INDEX_TO_CHARSET[69] = "US-ASCII";
            INDEX_TO_CHARSET[70] = getJavaEncodingForMysqlEncoding("greek", null);
            INDEX_TO_CHARSET[71] = getJavaEncodingForMysqlEncoding("hebrew", null);
            INDEX_TO_CHARSET[72] = "US-ASCII";
            INDEX_TO_CHARSET[73] = "Cp895";
            INDEX_TO_CHARSET[74] = getJavaEncodingForMysqlEncoding("koi8r", null);
            INDEX_TO_CHARSET[75] = "KOI8_r";
            INDEX_TO_CHARSET[76] = NOT_USED;
            INDEX_TO_CHARSET[77] = getJavaEncodingForMysqlEncoding("latin2", null);
            INDEX_TO_CHARSET[78] = getJavaEncodingForMysqlEncoding("latin5", null);
            INDEX_TO_CHARSET[79] = getJavaEncodingForMysqlEncoding("latin7", null);
            INDEX_TO_CHARSET[80] = getJavaEncodingForMysqlEncoding("cp850", null);
            INDEX_TO_CHARSET[81] = getJavaEncodingForMysqlEncoding("cp852", null);
            INDEX_TO_CHARSET[82] = NOT_USED;
            INDEX_TO_CHARSET[83] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[84] = getJavaEncodingForMysqlEncoding("big5", null);
            INDEX_TO_CHARSET[85] = getJavaEncodingForMysqlEncoding("euckr", null);
            INDEX_TO_CHARSET[86] = getJavaEncodingForMysqlEncoding("gb2312", null);
            INDEX_TO_CHARSET[87] = getJavaEncodingForMysqlEncoding("gbk", null);
            INDEX_TO_CHARSET[88] = getJavaEncodingForMysqlEncoding("sjis", null);
            INDEX_TO_CHARSET[89] = getJavaEncodingForMysqlEncoding("tis620", null);
            INDEX_TO_CHARSET[90] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[91] = getJavaEncodingForMysqlEncoding("ujis", null);
            INDEX_TO_CHARSET[92] = "US-ASCII";
            INDEX_TO_CHARSET[93] = "US-ASCII";
            INDEX_TO_CHARSET[94] = getJavaEncodingForMysqlEncoding("latin1", null);
            INDEX_TO_CHARSET[95] = getJavaEncodingForMysqlEncoding("cp932", null);
            INDEX_TO_CHARSET[96] = getJavaEncodingForMysqlEncoding("cp932", null);
            INDEX_TO_CHARSET[97] = getJavaEncodingForMysqlEncoding("eucjpms", null);
            INDEX_TO_CHARSET[98] = getJavaEncodingForMysqlEncoding("eucjpms", null);
            for (int i = 99; i < 128; i++) {
                INDEX_TO_CHARSET[i] = NOT_USED;
            }
            INDEX_TO_CHARSET[128] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[129] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[130] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[131] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[132] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[133] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[134] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[135] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[136] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[137] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[138] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[139] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[140] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[141] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[142] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[143] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[144] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[145] = getJavaEncodingForMysqlEncoding("ucs2", null);
            INDEX_TO_CHARSET[146] = getJavaEncodingForMysqlEncoding("ucs2", null);
            for (int i2 = 147; i2 < 192; i2++) {
                INDEX_TO_CHARSET[i2] = NOT_USED;
            }
            INDEX_TO_CHARSET[192] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[193] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[194] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[195] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[196] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[197] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[198] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[199] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[200] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[201] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[202] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[203] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[204] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[205] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[206] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[207] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[208] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[209] = getJavaEncodingForMysqlEncoding("utf8", null);
            INDEX_TO_CHARSET[210] = getJavaEncodingForMysqlEncoding("utf8", null);
            for (int i3 = 1; i3 < INDEX_TO_CHARSET.length; i3++) {
                if (INDEX_TO_CHARSET[i3] == null) {
                    throw new RuntimeException(new StringBuffer().append("Assertion failure: No mapping from charset index ").append(i3).append(" to a Java character set").toString());
                }
            }
        } catch (SQLException e) {
        }
        INDEX_TO_COLLATION = new String[211];
        INDEX_TO_COLLATION[1] = "big5_chinese_ci";
        INDEX_TO_COLLATION[2] = "latin2_czech_cs";
        INDEX_TO_COLLATION[3] = "dec8_swedish_ci";
        INDEX_TO_COLLATION[4] = "cp850_general_ci";
        INDEX_TO_COLLATION[5] = "latin1_german1_ci";
        INDEX_TO_COLLATION[6] = "hp8_english_ci";
        INDEX_TO_COLLATION[7] = "koi8r_general_ci";
        INDEX_TO_COLLATION[8] = "latin1_swedish_ci";
        INDEX_TO_COLLATION[9] = "latin2_general_ci";
        INDEX_TO_COLLATION[10] = "swe7_swedish_ci";
        INDEX_TO_COLLATION[11] = "ascii_general_ci";
        INDEX_TO_COLLATION[12] = "ujis_japanese_ci";
        INDEX_TO_COLLATION[13] = "sjis_japanese_ci";
        INDEX_TO_COLLATION[14] = "cp1251_bulgarian_ci";
        INDEX_TO_COLLATION[15] = "latin1_danish_ci";
        INDEX_TO_COLLATION[16] = "hebrew_general_ci";
        INDEX_TO_COLLATION[18] = "tis620_thai_ci";
        INDEX_TO_COLLATION[19] = "euckr_korean_ci";
        INDEX_TO_COLLATION[20] = "latin7_estonian_cs";
        INDEX_TO_COLLATION[21] = "latin2_hungarian_ci";
        INDEX_TO_COLLATION[22] = "koi8u_general_ci";
        INDEX_TO_COLLATION[23] = "cp1251_ukrainian_ci";
        INDEX_TO_COLLATION[24] = "gb2312_chinese_ci";
        INDEX_TO_COLLATION[25] = "greek_general_ci";
        INDEX_TO_COLLATION[26] = "cp1250_general_ci";
        INDEX_TO_COLLATION[27] = "latin2_croatian_ci";
        INDEX_TO_COLLATION[28] = "gbk_chinese_ci";
        INDEX_TO_COLLATION[29] = "cp1257_lithuanian_ci";
        INDEX_TO_COLLATION[30] = "latin5_turkish_ci";
        INDEX_TO_COLLATION[31] = "latin1_german2_ci";
        INDEX_TO_COLLATION[32] = "armscii8_general_ci";
        INDEX_TO_COLLATION[33] = "utf8_general_ci";
        INDEX_TO_COLLATION[34] = "cp1250_czech_cs";
        INDEX_TO_COLLATION[35] = "ucs2_general_ci";
        INDEX_TO_COLLATION[36] = "cp866_general_ci";
        INDEX_TO_COLLATION[37] = "keybcs2_general_ci";
        INDEX_TO_COLLATION[38] = "macce_general_ci";
        INDEX_TO_COLLATION[39] = "macroman_general_ci";
        INDEX_TO_COLLATION[40] = "cp852_general_ci";
        INDEX_TO_COLLATION[41] = "latin7_general_ci";
        INDEX_TO_COLLATION[42] = "latin7_general_cs";
        INDEX_TO_COLLATION[43] = "macce_bin";
        INDEX_TO_COLLATION[44] = "cp1250_croatian_ci";
        INDEX_TO_COLLATION[47] = "latin1_bin";
        INDEX_TO_COLLATION[48] = "latin1_general_ci";
        INDEX_TO_COLLATION[49] = "latin1_general_cs";
        INDEX_TO_COLLATION[50] = "cp1251_bin";
        INDEX_TO_COLLATION[51] = "cp1251_general_ci";
        INDEX_TO_COLLATION[52] = "cp1251_general_cs";
        INDEX_TO_COLLATION[53] = "macroman_bin";
        INDEX_TO_COLLATION[57] = "cp1256_general_ci";
        INDEX_TO_COLLATION[58] = "cp1257_bin";
        INDEX_TO_COLLATION[59] = "cp1257_general_ci";
        INDEX_TO_COLLATION[63] = "binary";
        INDEX_TO_COLLATION[64] = "armscii8_bin";
        INDEX_TO_COLLATION[65] = "ascii_bin";
        INDEX_TO_COLLATION[66] = "cp1250_bin";
        INDEX_TO_COLLATION[67] = "cp1256_bin";
        INDEX_TO_COLLATION[68] = "cp866_bin";
        INDEX_TO_COLLATION[69] = "dec8_bin";
        INDEX_TO_COLLATION[70] = "greek_bin";
        INDEX_TO_COLLATION[71] = "hebrew_bin";
        INDEX_TO_COLLATION[72] = "hp8_bin";
        INDEX_TO_COLLATION[73] = "keybcs2_bin";
        INDEX_TO_COLLATION[74] = "koi8r_bin";
        INDEX_TO_COLLATION[75] = "koi8u_bin";
        INDEX_TO_COLLATION[77] = "latin2_bin";
        INDEX_TO_COLLATION[78] = "latin5_bin";
        INDEX_TO_COLLATION[79] = "latin7_bin";
        INDEX_TO_COLLATION[80] = "cp850_bin";
        INDEX_TO_COLLATION[81] = "cp852_bin";
        INDEX_TO_COLLATION[82] = "swe7_bin";
        INDEX_TO_COLLATION[83] = "utf8_bin";
        INDEX_TO_COLLATION[84] = "big5_bin";
        INDEX_TO_COLLATION[85] = "euckr_bin";
        INDEX_TO_COLLATION[86] = "gb2312_bin";
        INDEX_TO_COLLATION[87] = "gbk_bin";
        INDEX_TO_COLLATION[88] = "sjis_bin";
        INDEX_TO_COLLATION[89] = "tis620_bin";
        INDEX_TO_COLLATION[90] = "ucs2_bin";
        INDEX_TO_COLLATION[91] = "ujis_bin";
        INDEX_TO_COLLATION[92] = "geostd8_general_ci";
        INDEX_TO_COLLATION[93] = "geostd8_bin";
        INDEX_TO_COLLATION[94] = "latin1_spanish_ci";
        INDEX_TO_COLLATION[95] = "cp932_japanese_ci";
        INDEX_TO_COLLATION[96] = "cp932_bin";
        INDEX_TO_COLLATION[97] = "eucjpms_japanese_ci";
        INDEX_TO_COLLATION[98] = "eucjpms_bin";
        INDEX_TO_COLLATION[99] = "cp1250_polish_ci";
        INDEX_TO_COLLATION[128] = "ucs2_unicode_ci";
        INDEX_TO_COLLATION[129] = "ucs2_icelandic_ci";
        INDEX_TO_COLLATION[130] = "ucs2_latvian_ci";
        INDEX_TO_COLLATION[131] = "ucs2_romanian_ci";
        INDEX_TO_COLLATION[132] = "ucs2_slovenian_ci";
        INDEX_TO_COLLATION[133] = "ucs2_polish_ci";
        INDEX_TO_COLLATION[134] = "ucs2_estonian_ci";
        INDEX_TO_COLLATION[135] = "ucs2_spanish_ci";
        INDEX_TO_COLLATION[136] = "ucs2_swedish_ci";
        INDEX_TO_COLLATION[137] = "ucs2_turkish_ci";
        INDEX_TO_COLLATION[138] = "ucs2_czech_ci";
        INDEX_TO_COLLATION[139] = "ucs2_danish_ci";
        INDEX_TO_COLLATION[140] = "ucs2_lithuanian_ci ";
        INDEX_TO_COLLATION[141] = "ucs2_slovak_ci";
        INDEX_TO_COLLATION[142] = "ucs2_spanish2_ci";
        INDEX_TO_COLLATION[143] = "ucs2_roman_ci";
        INDEX_TO_COLLATION[144] = "ucs2_persian_ci";
        INDEX_TO_COLLATION[145] = "ucs2_esperanto_ci";
        INDEX_TO_COLLATION[146] = "ucs2_hungarian_ci";
        INDEX_TO_COLLATION[192] = "utf8_unicode_ci";
        INDEX_TO_COLLATION[193] = "utf8_icelandic_ci";
        INDEX_TO_COLLATION[194] = "utf8_latvian_ci";
        INDEX_TO_COLLATION[195] = "utf8_romanian_ci";
        INDEX_TO_COLLATION[196] = "utf8_slovenian_ci";
        INDEX_TO_COLLATION[197] = "utf8_polish_ci";
        INDEX_TO_COLLATION[198] = "utf8_estonian_ci";
        INDEX_TO_COLLATION[199] = "utf8_spanish_ci";
        INDEX_TO_COLLATION[200] = "utf8_swedish_ci";
        INDEX_TO_COLLATION[201] = "utf8_turkish_ci";
        INDEX_TO_COLLATION[202] = "utf8_czech_ci";
        INDEX_TO_COLLATION[203] = "utf8_danish_ci";
        INDEX_TO_COLLATION[204] = "utf8_lithuanian_ci ";
        INDEX_TO_COLLATION[205] = "utf8_slovak_ci";
        INDEX_TO_COLLATION[206] = "utf8_spanish2_ci";
        INDEX_TO_COLLATION[207] = "utf8_roman_ci";
        INDEX_TO_COLLATION[208] = "utf8_persian_ci";
        INDEX_TO_COLLATION[209] = "utf8_esperanto_ci";
        INDEX_TO_COLLATION[210] = "utf8_hungarian_ci";
        Map indexMap = new TreeMap(String.CASE_INSENSITIVE_ORDER);
        for (int i4 = 0; i4 < INDEX_TO_CHARSET.length; i4++) {
            if (INDEX_TO_CHARSET[i4] != null) {
                indexMap.put(INDEX_TO_CHARSET[i4], Constants.integerValueOf(i4));
            }
        }
        MYSQL_ENCODING_NAME_TO_CHARSET_INDEX_MAP = Collections.unmodifiableMap(indexMap);
        Map tempMap = new HashMap();
        tempMap.put("czech", "latin2");
        tempMap.put("danish", "latin1");
        tempMap.put("dutch", "latin1");
        tempMap.put("english", "latin1");
        tempMap.put("estonian", "latin7");
        tempMap.put("french", "latin1");
        tempMap.put("german", "latin1");
        tempMap.put("greek", "greek");
        tempMap.put("hungarian", "latin2");
        tempMap.put("italian", "latin1");
        tempMap.put("japanese", "ujis");
        tempMap.put("japanese-sjis", "sjis");
        tempMap.put("korean", "euckr");
        tempMap.put("norwegian", "latin1");
        tempMap.put("norwegian-ny", "latin1");
        tempMap.put("polish", "latin2");
        tempMap.put("portuguese", "latin1");
        tempMap.put("romanian", "latin2");
        tempMap.put("russian", "koi8r");
        tempMap.put("serbian", "cp1250");
        tempMap.put("slovak", "latin2");
        tempMap.put("spanish", "latin1");
        tempMap.put("swedish", "latin1");
        tempMap.put("ukrainian", "koi8u");
        ERROR_MESSAGE_FILE_TO_MYSQL_CHARSET_MAP = Collections.unmodifiableMap(tempMap);
    }

    public static final String getJavaEncodingForMysqlEncoding(String mysqlEncoding, Connection conn) throws SQLException {
        if (conn != null && conn.versionMeetsMinimum(4, 1, 0) && "latin1".equalsIgnoreCase(mysqlEncoding)) {
            return "Cp1252";
        }
        return (String) MYSQL_TO_JAVA_CHARSET_MAP.get(mysqlEncoding);
    }

    public static final String getMysqlEncodingForJavaEncoding(String javaEncodingUC, Connection conn) throws SQLException {
        VersionedStringProperty versionedProp;
        List mysqlEncodings = (List) JAVA_UC_TO_MYSQL_CHARSET_MAP.get(javaEncodingUC);
        if (mysqlEncodings != null) {
            Iterator iter = mysqlEncodings.iterator();
            VersionedStringProperty versionedStringProperty = null;
            while (true) {
                versionedProp = versionedStringProperty;
                if (!iter.hasNext()) {
                    break;
                }
                VersionedStringProperty propToCheck = (VersionedStringProperty) iter.next();
                if (conn == null) {
                    return propToCheck.toString();
                }
                if (versionedProp != null && !versionedProp.preferredValue && versionedProp.majorVersion == propToCheck.majorVersion && versionedProp.minorVersion == propToCheck.minorVersion && versionedProp.subminorVersion == propToCheck.subminorVersion) {
                    return versionedProp.toString();
                }
                if (!propToCheck.isOkayForVersion(conn)) {
                    break;
                }
                if (propToCheck.preferredValue) {
                    return propToCheck.toString();
                }
                versionedStringProperty = propToCheck;
            }
            if (versionedProp != null) {
                return versionedProp.toString();
            }
            return null;
        }
        return null;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static final int getNumberOfCharsetsConfigured() {
        return MYSQL_TO_JAVA_CHARSET_MAP.size() / 2;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static final String getCharacterEncodingForErrorMessages(ConnectionImpl conn) throws SQLException {
        String javaEncoding;
        String errorMessageFile = conn.getServerVariable("language");
        if (errorMessageFile == null || errorMessageFile.length() == 0) {
            return "Cp1252";
        }
        int endWithoutSlash = errorMessageFile.length();
        if (errorMessageFile.endsWith("/") || errorMessageFile.endsWith("\\")) {
            endWithoutSlash--;
        }
        int lastSlashIndex = errorMessageFile.lastIndexOf(47, endWithoutSlash - 1);
        if (lastSlashIndex == -1) {
            lastSlashIndex = errorMessageFile.lastIndexOf(92, endWithoutSlash - 1);
        }
        if (lastSlashIndex == -1) {
            lastSlashIndex = 0;
        }
        if (lastSlashIndex == endWithoutSlash || endWithoutSlash < lastSlashIndex) {
            return "Cp1252";
        }
        String errorMessageEncodingMysql = (String) ERROR_MESSAGE_FILE_TO_MYSQL_CHARSET_MAP.get(errorMessageFile.substring(lastSlashIndex + 1, endWithoutSlash));
        if (errorMessageEncodingMysql == null || (javaEncoding = getJavaEncodingForMysqlEncoding(errorMessageEncodingMysql, conn)) == null) {
            return "Cp1252";
        }
        return javaEncoding;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static final boolean isAliasForSjis(String encoding) {
        return "SJIS".equalsIgnoreCase(encoding) || "WINDOWS-31J".equalsIgnoreCase(encoding) || "MS932".equalsIgnoreCase(encoding) || "SHIFT_JIS".equalsIgnoreCase(encoding) || "CP943".equalsIgnoreCase(encoding);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static final boolean isMultibyteCharset(String javaEncodingName) {
        String javaEncodingNameUC = javaEncodingName.toUpperCase(Locale.ENGLISH);
        return MULTIBYTE_CHARSETS.containsKey(javaEncodingNameUC);
    }

    private static void populateMapWithKeyValuePairs(String configKey, Map mapToPopulate, boolean addVersionedProperties, boolean addUppercaseKeys) {
        String javaToMysqlConfig = CHARSET_CONFIG.getProperty(configKey);
        if (javaToMysqlConfig != null) {
            List<String> mappings = StringUtils.split(javaToMysqlConfig, ",", true);
            if (mappings != null) {
                for (String aMapping : mappings) {
                    List parsedPair = StringUtils.split(aMapping, "=", true);
                    if (parsedPair.size() == 2) {
                        String key = parsedPair.get(0).toString();
                        String value = parsedPair.get(1).toString();
                        if (addVersionedProperties) {
                            List versionedProperties = (List) mapToPopulate.get(key);
                            if (versionedProperties == null) {
                                versionedProperties = new ArrayList();
                                mapToPopulate.put(key, versionedProperties);
                            }
                            VersionedStringProperty verProp = new VersionedStringProperty(value);
                            versionedProperties.add(verProp);
                            if (addUppercaseKeys) {
                                String keyUc = key.toUpperCase(Locale.ENGLISH);
                                List versionedProperties2 = (List) mapToPopulate.get(keyUc);
                                if (versionedProperties2 == null) {
                                    versionedProperties2 = new ArrayList();
                                    mapToPopulate.put(keyUc, versionedProperties2);
                                }
                                versionedProperties2.add(verProp);
                            }
                        } else {
                            mapToPopulate.put(key, value);
                            if (addUppercaseKeys) {
                                mapToPopulate.put(key.toUpperCase(Locale.ENGLISH), value);
                            }
                        }
                    } else {
                        throw new RuntimeException(new StringBuffer().append("Syntax error in Charsets.properties resource for token \"").append(aMapping).append("\".").toString());
                    }
                }
                return;
            }
            throw new RuntimeException(new StringBuffer().append("Missing/corrupt entry for \"").append(configKey).append("\" in Charsets.properties.").toString());
        }
        throw new RuntimeException(new StringBuffer().append("Could not find configuration value \"").append(configKey).append("\" in Charsets.properties resource").toString());
    }

    public static int getCharsetIndexForMysqlEncodingName(String name) {
        Integer asInt;
        if (name == null || (asInt = (Integer) MYSQL_ENCODING_NAME_TO_CHARSET_INDEX_MAP.get(name)) == null) {
            return 0;
        }
        return asInt.intValue();
    }
}
